import os
import subprocess

from absl import flags
from absl import logging

import common

FLAGS = flags.FLAGS
flags.DEFINE_string(
    "hhblits_bin",
    os.path.join(common.HHSUITE_DIR, "bin/hhblits"),
    "hhblits binary path",
)

flags.DEFINE_integer("hhb_cpu", 16, "Number of CPUs used by hhblits")


def hhblits(infile, oa3m, db, evalue, cov, n_iter=1):
    """Search `infile` against `db` using hhblits.

    Keyword arguments:
    infile -- input fasta (or a3m) format file
    oa3m   -- output a3m format file
    db     -- hhsuite database path
    evalue -- E-value
    """
    cmd = (
        f"{FLAGS.hhblits_bin}"
        f" -i {infile}"
        f" -o {os.path.splitext(oa3m)[0] + '.hhr'}"
        f" -oa3m {oa3m}"
        f" -cov {cov}"
        f" -d {db}"
        f" -n {n_iter}"
        f" -e {evalue}"
        f" -cpu {FLAGS.hhb_cpu}"
        f" -id 99"
        f" -diff inf"
        f" -maxfilt 20000"
    )
    logging.info(f"Run hhblits: {cmd}")
    subprocess.run(cmd, shell=True)
