import os
import subprocess

from absl import flags
from absl import logging

import common

FLAGS = flags.FLAGS

flags.DEFINE_integer("hmmer_cpu", 16, "Number of CPUs used by hmmsearch")


def hmmer(infile, oa3m, db, evalue):
    """Search `infile` against `db` using hhblits.

    Keyword arguments:
    infile -- input fasta (or a3m) format file
    oa3m   -- output a3m format file
    db     -- hhsuite database path
    evalue -- E-value
    """
    odir = os.path.dirname(oa3m)
    name = os.path.splitext(os.path.basename(oa3m))[0]
    # 1. build HMM file
    cmd = (
        f"sed 's/[a-z]//g' {infile} > {os.path.join(odir, name + '.aln')}"
        f"&& {os.path.join(common.HMMER_DIR, 'bin/hmmbuild')}"
        f" --symfrac 0"
        f" {os.path.join(odir, name + '.hmm')}"
        f" {os.path.join(odir, name + '.aln')}"
    )

    logging.info(f"Build HMM file: {cmd}")
    subprocess.run(cmd, shell=True)

    # 2. search against sequence databases
    cmd = (
        f"{os.path.join(common.HMMER_DIR, 'bin/hmmsearch')}"
        f" --cpu {FLAGS.hmmer_cpu}"
        f" -E {evalue}"
        f" --domE {evalue}"
        f" --incE {evalue}"
        f" --incdomE {evalue}"
        f" --noali"
        f" --notextw"
        f" -A {os.path.join(odir, name + '.sto')}"
        f" {os.path.join(odir, name + '.hmm')}"
        f" {db}"
    )
    logging.info(f"Run hmmsearch: {cmd}")
    subprocess.run(cmd, shell=True)

    # 3. convert output to A3M
    cmd = (
        f"head -2 {infile} > {os.path.join(odir, name + '.a3m')}"
        f"&& grep -v '^#' {os.path.join(odir, name + '.sto')} | "
        'awk \'{if(NF==2){print ">"$1"\\n"$2}}\' | '
        f"sed 's/\.//g' >> {os.path.join(odir, name + '.a3m')}"
    )
    logging.info(f"Run hmmsearch: {cmd}")
    subprocess.run(cmd, shell=True)
