#!/usr/bin/env python
import os

from absl import app
from absl import flags
from absl import logging

from zetahit_impl import zetahit_main

FLAGS = flags.FLAGS

flags.DEFINE_string("fasta", None, "Fasta format input")
flags.DEFINE_string("odir", None, "Output directory")
flags.DEFINE_string("tmpdir", "/dev/shm", "Temporary directory")

flags.DEFINE_boolean("use_uniref30", False, "Use UniRef30 db")
flags.DEFINE_string(
    "uniref30_db",
    "/data/database/hhsuite/hhsuite_dbs/UniRef30_2020_02/UniRef30_2020_02",
    "UniRef30 hhsuite database path",
)

flags.DEFINE_boolean("use_uniref90", False, "Use UniRef90 db")
flags.DEFINE_string(
    "uniref90_db",
    "/mnt/databases/uniref90.fasta",
    "UniRef90 hmmer database path",
)

flags.DEFINE_boolean("use_bfd30", False, "Use BFD30 db")
flags.DEFINE_string(
    "bfd30_db",
    "/data/database/hhsuite/hhsuite_dbs/bfd30_2019_03/bfd30",
    "BFD30 hhsuite database path",
)

flags.DEFINE_boolean("use_mgnify90", False, "Use MGnify90 db")
flags.DEFINE_string(
    "mgnify90_db",
    "/mnt/databases/mgy_clusters.fa",
    "MGnify90 hmmer database path",
)


def main(argv):
    zetahit_main()


if __name__ == "__main__":
    flags.mark_flag_as_required("fasta")
    flags.mark_flag_as_required("odir")
    app.run(main)
